(*==========================================================================================
| Author........: Daniel Wiss
| Mail..........: d.wiss@gmx.net
|-------------------------------------------------------------------------------------------
| Filename......: wssSpeedButton.pas
| Info..........: Extended with WordWrap functionality to write Caption on 2 lines
| Develop.system: Windows 2000
| Compiler/Tools: Delphi 5.0
|-------------------------------------------------------------------------------------------
| History:
| Date        Vers. Vis.| Reason
|-------------------------------------------------------------------------------------------
| 05.04.2001  1.00  Wss | Initial Release
|=========================================================================================*)
unit wssSpeedButton;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons;

type
  TwssSpeedButton = class(TSpeedButton)
  private
    fCaption: String;
    fWordWrap: Boolean;
    fWordWrapChar: Char;
    function GetCaption: String;
    procedure SetCaption(const Value: String);
    procedure SetWordWrap(const Value: Boolean);
    procedure SetWordWrapChar(const Value: Char);
  protected
    procedure DoInheritedCaption;
    procedure Resize; override;
  public
    constructor Create(aOwner: TComponent); override;
    procedure Paint; override;
  published
    property Caption: String read GetCaption write SetCaption;
    property WordWrapChar: Char read fWordWrapChar write SetWordWrapChar;
    property WordWrap: Boolean read fWordWrap write SetWordWrap;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Wss', [TwssSpeedButton]);
end;

//------------------------------------------------------------------------------
// TwssSpeedButton
//------------------------------------------------------------------------------
constructor TwssSpeedButton.Create(aOwner: TComponent);
begin
  inherited Create(aOwner);
  fCaption  := inherited Caption;
  fWordWrap := False;
end;
//------------------------------------------------------------------------------
procedure TwssSpeedButton.DoInheritedCaption;
begin
  if fWordWrap then
    inherited Caption := StringReplace(fCaption, fWordWrapChar, #10, [rfReplaceAll])
  else
    inherited Caption := fCaption;
end;
//------------------------------------------------------------------------------
function TwssSpeedButton.GetCaption: String;
begin
  Result := fCaption;
end;
//------------------------------------------------------------------------------
procedure TwssSpeedButton.Paint;
begin
  inherited Paint;
end;
//------------------------------------------------------------------------------
procedure TwssSpeedButton.Resize;
begin
  inherited Resize;
  DoInheritedCaption;
end;
//------------------------------------------------------------------------------
procedure TwssSpeedButton.SetCaption(const Value: String);
begin
  if Value <> fCaption then begin
    fCaption := Value;
    DoInheritedCaption;
  end;
end;
//------------------------------------------------------------------------------
procedure TwssSpeedButton.SetWordWrapChar(const Value: Char);
begin
  if Value <> fWordWrapChar then begin
    fWordWrapChar := Value;
    if fWordWrapChar = #0 then begin
      fWordWrapChar := ' ';
      fWordWrap := False;
    end;
    DoInheritedCaption;
  end;
end;
//------------------------------------------------------------------------------
procedure TwssSpeedButton.SetWordWrap(const Value: Boolean);
begin
  if Value <> fWordWrap then begin
    fWordWrap := Value;
    DoInheritedCaption;
  end;
end;
//------------------------------------------------------------------------------
end.

